@@ -15,17 +15,18 @@ VE.Jk.EB.SW2.Ratio <- function(VecY.s, VecX.s, VecPk.s, nII, VecPi.s, VecCluLab.
   if(any(VecPi.s<=0|VecPi.s>1)              ){stop("There are invalid values in VecPi.s.")                                                                                   }
   if(any(is.na(VecY.s))                     ){stop("There are missing values in VecY.s.")                                                                                    }
   if(any(is.na(VecX.s))                     ){stop("There are missing values in VecX.s.")                                                                                    }
+  if(any(VecX.s==0)                         ){warning("There are zero values in the denominator variable VecX.s.")                                      }
   if(length(nII) != 1                       ){stop(paste("nII must be a integer scalar, i.e. a vector of length 1 valued from 1 to", as.character(.Machine$integer.max),"."))}
   n                                          <- length(VecY.s)
   VecPi.sI                                   <- VecPi.s[!duplicated(VecCluLab.s)]
   VecCluSize.sI                              <- VecCluSize.s[!duplicated(VecCluLab.s)]
   nI                                         <- length(VecPi.sI)
   DoublenI                                   <- as.double(nI)
-  if(n != as.integer(length(VecPk.s))       ){stop("The lengths of VecY.s and VecPk.s are different.")                                                                       }
-  if(n != as.integer(length(VecX.s))        ){stop("The lengths of VecY.s and VecX.s are different.")                                                                        }
-  if(n != as.integer(length(VecCluLab.s))   ){stop("The lengths of VecY.s and VecCluLab.s are different.")                                                                   }
+  if(n != length(VecPk.s)                   ){stop("The lengths of VecY.s and VecPk.s are different.")                                                                       }
+  if(n != length(VecX.s)                    ){stop("The lengths of VecY.s and VecX.s are different.")                                                                        }
+  if(any(VecX.s==0)                         ){warning("There are zero values in the denominator variable VecX.s.")                                      }
+  if(n != length(VecCluLab.s)               ){stop("The lengths of VecY.s and VecCluLab.s are different.")                                                                   }
   if(n != as.integer(nI*nII)                ){stop("The lengths of VecY.s and (nI * nII) are different.")                                                                    }
-  if(any(VecX.s==0)                         ){stop("There are zero values in VecX.s. Division by zero is undefined.")                                                        }
   if(any(VecCluSize.s < nII)                ){stop("The value of nII is larger than the minimum cluster size in VecCluSize.s.")                                              }
   EstTheta                                   <- Est.Ratio(VecY.s, VecX.s, VecPk.s)
   VarianceClusters                           <- .C("VE_Jk_EB_SW2_Ratio_Clu",
